@@ -14,7 +14,10 @@ import cdktf_local_exec._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdktf-local-build", "0.0.99", __name__[0:-6], "cdktf-local-build@0.0.99.jsii.tgz"
+    "cdktf-local-build",
+    "0.0.100",
+    __name__[0:-6],
+    "cdktf-local-build@0.0.100.jsii.tgz",
 )
 
 __all__ = [
